@@ -12,15 +12,15 @@
 #  License for the specific language governing permissions and limitations
 #  under the License.
 
-from django.core import urlresolvers
 from django.test import RequestFactory
+from django.urls import reverse
 
 from monitoring.overview import constants
 from monitoring.overview import views
 from monitoring.test import helpers
 
 
-INDEX_URL = urlresolvers.reverse(
+INDEX_URL = reverse(
     constants.URL_PREFIX + 'index')
 
 
